<?php

namespace Drupal\oauth2_client\Service\Grant;

use Drupal\oauth2_client\OAuth2\Client\OptionProvider\ClientCredentialsOptionProvider;
use League\OAuth2\Client\Provider\Exception\IdentityProviderException;

/**
 * Handles Authorization Grants for the OAuth2 Client module.
 *
 * @deprecated in oauth2_client:8.x-3.1 and is removed from 4.0.
 *   This service class will be replaced by
 *   Drupal\oauth2_client\Plugin\Oauth2GrantType\ClientCredentials
 *   plugin in 4.x
 * @see https://www.drupal.org/node/3315847
 */
class ClientCredentialsGrantService extends Oauth2ClientGrantServiceBase {

  /**
   * {@inheritdoc}
   */
  public function getAccessToken($pluginId) {
    $client = $this->getClient($pluginId);
    $provider = $this->getProvider($pluginId);
    $optionProvider = $provider->getOptionProvider();
    // If the provider was just created, our OptionProvder must be set.
    if (!($optionProvider instanceof ClientCredentialsOptionProvider)) {
      $client = $this->getClient($pluginId);
      $provider->setOptionProvider(new ClientCredentialsOptionProvider($client));
    }

    try {
      $accessToken = $provider->getAccessToken('client_credentials', $client->getRequestOptions());

      $this->storeAccessToken($pluginId, $accessToken);
    }
    catch (IdentityProviderException $e) {
      // Failed to get the access token.
      watchdog_exception('OAuth2 Client', $e);
    }
  }

  /**
   * {@inheritdoc}
   */
  public function getGrantProvider($pluginId) {
    return $this->getProvider($pluginId);
  }

}
