<?php

namespace Drupal\oauth2_client\Service\Grant;

use Drupal\oauth2_client\OwnerCredentials;

/**
 * Handles Authorization Grants for the OAuth2 Client module.
 *
 * @deprecated in oauth2_client:8.x-3.1 and is removed from 4.0.
 *   This service class will be replaced by
 *   Drupal\oauth2_client\Plugin\Oauth2GrantType\ResourceOwner
 *   plugin in 4.x
 * @see https://www.drupal.org/node/3315847
 */
class ResourceOwnersCredentialsGrantService extends Oauth2ClientGrantServiceBase {

  /**
   * Storage for usernames and passwords keyed by plugin id.
   *
   * @var array
   */
  protected $usernamesPasswords;

  /**
   * {@inheritdoc}
   */
  public function getAccessToken($pluginId) {
    $client = $this->getClient($pluginId);
    $provider = $this->getProvider($pluginId);
    $credentials = $this->getUsernamePassword($pluginId);
    if (empty($credentials)) {
      throw new \RuntimeException('Missing username and password for client plugin ' . $pluginId);
    }
    $options = $client->getRequestOptions([
        'username' => $credentials['username'],
        'password' => $credentials['password'],
    ]);
    try {
      $accessToken = $provider->getAccessToken('password', $options);

      $this->storeAccessToken($pluginId, $accessToken);
    }
    catch (\Exception $e) {
      // Failed to get the access token.
      watchdog_exception('OAuth2 Client', $e);
    }
  }

  /**
   * {@inheritdoc}
   */
  public function getGrantProvider($pluginId) {
    return $this->getProvider($pluginId);
  }

  /**
   * Pass credentials in memory to be used in the oauth request.
   *
   * It may not be necessary, but storing by client id in case some edge
   * case has two or more client plugins operating on the same request.
   *
   * @param string $pluginId
   *   The id of the Oauth2Client plugin implementing this grant type.
   * @param \Drupal\oauth2_client\OwnerCredentials|null $credentials
   *   Owner credentials for resource_owner grants.
   */
  public function setUsernamePassword($pluginId, OwnerCredentials $credentials) {
    $this->usernamesPasswords[$pluginId] = [
      'username' => $credentials->getUsername(),
      'password' => $credentials->getPassword(),
    ];
  }

  /**
   * Gets credential pairs by plugin id.
   *
   * @param string $pluginId
   *   The id of the Oauth2Client plugin implementing this grant type.
   *
   * @return array
   *   Associative array with `username` and `password` keys.
   */
  protected function getUsernamePassword($pluginId) {
    return $this->usernamesPasswords[$pluginId] ?? [];
  }

}
